get_learning_objectives

Function get_learning_objectives 

pub fn get_learning_objectives(
    blocks: Vec<GutenbergBlock>,
) -> Result<String, Error>
Get learning objectives from a vec of Gutenberg blocks. Works recursively and inspects the inner blocks. Returns an empty string if no objectives are found. Returns the objectives of the whole Vec argument, joined together into a String.